from .xcolor import *
from .style import *
from .test import *

__all__ = [
    "Color",
    "BLACK",
    "RED",
    "GREEN",
    "YELLOW",
    "BLUE",
    "MAGENTA",
    "CYAN",
    "WHITE",
    "BLACKA",
    "REDA",
    "GREENA",
    "YELLOWA",
    "BLUEA",
    "MAGENTAA",
    "CYANA",
    "WHITEA",
    "BLACKB",
    "REDB",
    "GREENB",
    "YELLOWB",
    "BLUEB",
    "MAGENTAB",
    "CYANB",
    "WHITEB",
    "IBLACK",
    "IRED",
    "IGREEN",
    "IYELLOW",
    "IBLUE",
    "IMAGENTA",
    "ICYAN",
    "IWHITE",
    "IBLACKA",
    "IREDA",
    "IGREENA",
    "IYELLOWA",
    "IBLUEA",
    "IMAGENTAA",
    "ICYANA",
    "IWHITEA",
    "IBLACKB",
    "IREDB",
    "IGREENB",
    "IYELLOWB",
    "IBLUEB",
    "IMAGENTAB",
    "ICYANB",
    "IWHITEB",
    "UBLACK",
    "URED",
    "UGREEN",
    "UYELLOW",
    "UBLUE",
    "UMAGENTA",
    "UCYAN",
    "UWHITE",
    "UBLACKA",
    "UREDA",
    "UGREENA",
    "UYELLOWA",
    "UBLUEA",
    "UMAGENTAA",
    "UCYANA",
    "UWHITEA",
    "UBLACKB",
    "UREDB",
    "UGREENB",
    "UYELLOWB",
    "UBLUEB",
    "UMAGENTAB",
    "UCYANB",
    "UWHITEB",
    "TBLACK",
    "TRED",
    "TGREEN",
    "TYELLOW",
    "TBLUE",
    "TMAGENTA",
    "TCYAN",
    "TWHITE",
    "TBLACKA",
    "TREDA",
    "TGREENA",
    "TYELLOWA",
    "TBLUEA",
    "TMAGENTAA",
    "TCYANA",
    "TWHITEA",
    "TBLACKB",
    "TREDB",
    "TGREENB",
    "TYELLOWB",
    "TBLUEB",
    "TMAGENTAB",
    "TCYANB",
    "TWHITEB",
    "BBLACK",
    "BRED",
    "BGREEN",
    "BYELLOW",
    "BBLUE",
    "BMAGENTA",
    "BCYAN",
    "BWHITE",
    "test_color",
    "test_style",
]
