from .xcolor import Color

BLACK = Color("Black")
RED = Color("Red")
GREEN = Color("Green")
YELLOW = Color("Yellow")
BLUE = Color("Blue")
MAGENTA = Color("Magenta")
CYAN = Color("Cyan")
WHITE = Color("White")

BLACKA = Color("BlackA")
REDA = Color("RedA")
GREENA = Color("GreenA")
YELLOWA = Color("YellowA")
BLUEA = Color("BlueA")
MAGENTAA = Color("MagentaA")
CYANA = Color("CyanA")
WHITEA = Color("WhiteA")

BLACKB = Color("BlackB")
REDB = Color("RedB")
GREENB = Color("GreenB")
YELLOWB = Color("YellowB")
BLUEB = Color("BlueB")
MAGENTAB = Color("MagentaB")
CYANB = Color("CyanB")
WHITEB = Color("WhiteB")

IBLACK = Color("Black", "Italic")
IRED = Color("Red", "Italic")
IGREEN = Color("Green", "Italic")
IYELLOW = Color("Yellow", "Italic")
IBLUE = Color("Blue", "Italic")
IMAGENTA = Color("Magenta", "Italic")
ICYAN = Color("Cyan", "Italic")
IWHITE = Color("White", "Italic")

IBLACKA = Color("BlackA", "Italic")
IREDA = Color("RedA", "Italic")
IGREENA = Color("GreenA", "Italic")
IYELLOWA = Color("YellowA", "Italic")
IBLUEA = Color("BlueA", "Italic")
IMAGENTAA = Color("MagentaA", "Italic")
ICYANA= Color("CyanA", "Italic")
IWHITEA = Color("WhiteA", "Italic")

IBLACKB = Color("BlackB", "Italic")
IREDB = Color("RedB", "Italic")
IGREENB = Color("GreenB", "Italic")
IYELLOWB = Color("YellowB", "Italic")
IBLUEB = Color("BlueB", "Italic")
IMAGENTAB = Color("MagentaB", "Italic")
ICYANB = Color("CyanB", "Italic")
IWHITEB = Color("WhiteB", "Italic")

UBLACK = Color("Black", "Underline")
URED = Color("Red", "Underline")
UGREEN = Color("Green", "Underline")
UYELLOW = Color("Yellow", "Underline")
UBLUE = Color("Blue", "Underline")
UMAGENTA = Color("Magenta", "Underline")
UCYAN = Color("Cyan", "Underline")
UWHITE = Color("White", "Underline")

UBLACKA = Color("BlackA", "Underline")
UREDA = Color("RedA", "Underline")
UGREENA = Color("GreenA", "Underline")
UYELLOWA = Color("YellowA", "Underline")
UBLUEA = Color("BlueA", "Underline")
UMAGENTAA = Color("MagentaA", "Underline")
UCYANA = Color("CyanA", "Underline")
UWHITEA = Color("WhiteA", "Underline")

UBLACKB = Color("BlackB", "Underline")
UREDB = Color("RedB", "Underline")
UGREENB = Color("GreenB", "Underline")
UYELLOWB = Color("YellowB", "Underline")
UBLUEB = Color("BlueB", "Underline")
UMAGENTAB = Color("MagentaB", "Underline")
UCYANB = Color("CyanB", "Underline")
UWHITEB = Color("WhiteB", "Underline")

TBLACK = Color("Black", "Throughline")
TRED = Color("Red", "Throughline")
TGREEN = Color("Green", "Throughline")
TYELLOW = Color("Yellow", "Throughline")
TBLUE = Color("Blue", "Throughline")
TMAGENTA = Color("Magenta", "Throughline")
TCYAN = Color("Cyan", "Throughline")
TWHITE = Color("White", "Throughline")

TBLACKA = Color("BlackA", "Throughline")
TREDA = Color("RedA", "Throughline")
TGREENA = Color("GreenA", "Throughline")
TYELLOWA = Color("YellowA", "Throughline")
TBLUEA = Color("BlueA", "Throughline")
TMAGENTAA = Color("MagentaA", "Throughline")
TCYANA = Color("CyanA", "Throughline")
TWHITEA = Color("WhiteA", "Throughline")

TBLACKB = Color("BlackB", "Throughline")
TREDB = Color("RedB", "Throughline")
TGREENB = Color("GreenB", "Throughline")
TYELLOWB = Color("YellowB", "Throughline")
TBLUEB = Color("BlueB", "Throughline")
TMAGENTAB = Color("MagentaB", "Throughline")
TCYANB = Color("CyanB", "Throughline")
TWHITEB = Color("WhiteB", "Throughline")

BBLACK = Color("Black", "Bold")
BRED = Color("Red", "Bold")
BGREEN = Color("Green", "Bold")
BYELLOW = Color("Yellow", "Bold")
BBLUE = Color("Blue", "Bold")
BMAGENTA = Color("Magenta", "Bold")
BCYAN = Color("Cyan", "Bold")
BWHITE = Color("White", "Bold")
